@@ -120,6 +120,14 @@ class Device(object):
                     msg,
         ))
 
+    def log(self, msg):
+        """ sends a debug-level message to the logger
+
+        This method is used so often, that a smaller version of it is quite
+        comfortable.
+        """
+        self.log(msg)
+
     def __str__(self):
         return "{}({}):name={}".format(
                 self.__class__.__name__,
@@ -135,16 +143,19 @@ class Hydra(Device):
         """ update the device to current build from Jenkins.
         """
         self._logger.info("Attempt update to " + str(link or self._update_link))
+        if not self.do_resetupdate:
+            self.log("don't update due to MONK configuration")
+            return
         if not self.is_updated:
             out = self.cmd("do-update -c && get-update {} && do-update".format(
                 link if link else self._update_link,
                 ), expect="([lL]ogin: )|([cC]onnection\sto\s[^\s]*\sclosed\.)", timeout=600)
             if "closed" in self.conns[0].exp.after:
-                self._logger.debug("reset connection after reboot")
+                self.log("reset connection after reboot")
                 del self.conns[0]._exp
-            self._logger.debug("wait till device recovered from updating")
+            self.log("wait till device recovered from updating")
             time.sleep(240)
-            self._logger.debug("continue")
+            self.log("continue")
             if not self.is_updated:
                 error= "build:{};fw:{};out:{}".format(
                         self.latest_build,
@@ -158,6 +169,8 @@ class Hydra(Device):
     def __init__(self, *args, **kwargs):
         self._update_link = "http://hydraip-integration.internal.dresearch-fe.de:8080/view/HIPOS/job/HydraIP_UpdateV3_USB_Stick/lastSuccessfulBuild/artifact/rel-hudson/hyp-updateV3-hikirk.zip"
         self._jenkins_link = "http://hydraip-integration.internal.dresearch-fe.de:8080/view/HIPOS/job/daisy-hipos-dfe-closed-hikirk/api/json"
+        self.do_update = kwargs.pop("update",True)
+        self.do_resetconfig = kwargs.pop("resetconfig",True)
         super(Hydra, self).__init__(*args, **kwargs)
 
     @property
@@ -191,6 +204,11 @@ class Hydra(Device):
     def reset_config(self):
         """ reset the HydraIP configuration on the device
         """
+        if not self.do_resetupdate:
+            self.log("don't reset config due to MONK configuration")
+            return
+        # otherwise it might not really be a reset
+        self.cmd("rm /etc/drconfig/hydraip.json.good")
         self.cmd(
             msg="rm -rf /var/lib/connman/* && hip-activate-config --reset && sync && halt -p",
             timeout=150,
@@ -198,40 +216,8 @@ class Hydra(Device):
             login_timeout=20,
         )
         if "login" not in self.conns[0].exp.after.lower():
-            self._logger.debug("reset connection after config reset")
+            self.log("reset connection after config reset")
             del self.conns[0]._exp
-        self._logger.debug("wait till device recovered from config reset")
+        self.log("wait till device recovered from config reset")
         time.sleep(120)
-        self._logger.debug("continue")
-
-class DevelDevice(Hydra):
-    """ Use this class instead of your other classes for development purposes
-
-    It does not reset anything and does not update. Everything else should work
-    fine, though.
-    """
-
-    def update(self, link=None):
-        pass
-
-    def __init__(self, *args, **kwargs):
-        super(DevelDevice, self).__init__(*args, **kwargs)
-
-    @property
-    def latest_build(self):
-        return "not supported"
-
-    @property
-    def current_fw_version(self):
-        return "not supported"
-
-    @property
-    def has_newest_firmware(self):
-        return "not supported"
-
-    @property
-    def is_updated(self):
-        return True
-
-    def reset_config(self):
-        pass
+        self.log("continue")
